==> pdf-preview-0.1.0.tar.gz: pdf-preview-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pdf_preview']

package_data = \
{'': ['*'],
 'pdf_preview': ['pdfjs-dist/*',
                 'pdfjs-dist/build/*',
                 'pdfjs-dist/web/*',
                 'pdfjs-dist/web/cmaps/*',
                 'pdfjs-dist/web/images/*',
                 'pdfjs-dist/web/locale/*',
                 'pdfjs-dist/web/locale/ach/*',
                 'pdfjs-dist/web/locale/af/*',
                 'pdfjs-dist/web/locale/ak/*',
                 'pdfjs-dist/web/locale/an/*',
                 'pdfjs-dist/web/locale/ar/*',
                 'pdfjs-dist/web/locale/as/*',
                 'pdfjs-dist/web/locale/ast/*',
                 'pdfjs-dist/web/locale/az/*',
                 'pdfjs-dist/web/locale/be/*',
                 'pdfjs-dist/web/locale/bg/*',
                 'pdfjs-dist/web/locale/bn-BD/*',
                 'pdfjs-dist/web/locale/bn-IN/*',
                 'pdfjs-dist/web/locale/br/*',
                 'pdfjs-dist/web/locale/brx/*',
                 'pdfjs-dist/web/locale/bs/*',
                 'pdfjs-dist/web/locale/ca/*',
                 'pdfjs-dist/web/locale/cak/*',
                 'pdfjs-dist/web/locale/crh/*',
                 'pdfjs-dist/web/locale/cs/*',
                 'pdfjs-dist/web/locale/csb/*',
                 'pdfjs-dist/web/locale/cy/*',
                 'pdfjs-dist/web/locale/da/*',
                 'pdfjs-dist/web/locale/de/*',
                 'pdfjs-dist/web/locale/el/*',
                 'pdfjs-dist/web/locale/en-CA/*',
                 'pdfjs-dist/web/locale/en-GB/*',
                 'pdfjs-dist/web/locale/en-US/*',
                 'pdfjs-dist/web/locale/en-ZA/*',
                 'pdfjs-dist/web/locale/eo/*',
                 'pdfjs-dist/web/locale/es-AR/*',
                 'pdfjs-dist/web/locale/es-CL/*',
                 'pdfjs-dist/web/locale/es-ES/*',
                 'pdfjs-dist/web/locale/es-MX/*',
                 'pdfjs-dist/web/locale/et/*',
                 'pdfjs-dist/web/locale/eu/*',
                 'pdfjs-dist/web/locale/fa/*',
                 'pdfjs-dist/web/locale/ff/*',
                 'pdfjs-dist/web/locale/fi/*',
                 'pdfjs-dist/web/locale/fr/*',
                 'pdfjs-dist/web/locale/fy-NL/*',
                 'pdfjs-dist/web/locale/ga-IE/*',
                 'pdfjs-dist/web/locale/gd/*',
                 'pdfjs-dist/web/locale/gl/*',
                 'pdfjs-dist/web/locale/gn/*',
                 'pdfjs-dist/web/locale/gu-IN/*',
                 'pdfjs-dist/web/locale/he/*',
                 'pdfjs-dist/web/locale/hi-IN/*',
                 'pdfjs-dist/web/locale/hr/*',
                 'pdfjs-dist/web/locale/hsb/*',
                 'pdfjs-dist/web/locale/hto/*',
                 'pdfjs-dist/web/locale/hu/*',
                 'pdfjs-dist/web/locale/hy-AM/*',
                 'pdfjs-dist/web/locale/ia/*',
                 'pdfjs-dist/web/locale/id/*',
                 'pdfjs-dist/web/locale/is/*',
                 'pdfjs-dist/web/locale/it/*',
                 'pdfjs-dist/web/locale/ja/*',
                 'pdfjs-dist/web/locale/ka/*',
                 'pdfjs-dist/web/locale/kab/*',
                 'pdfjs-dist/web/locale/kk/*',
                 'pdfjs-dist/web/locale/km/*',
                 'pdfjs-dist/web/locale/kn/*',
                 'pdfjs-dist/web/locale/ko/*',
                 'pdfjs-dist/web/locale/kok/*',
                 'pdfjs-dist/web/locale/ks/*',
                 'pdfjs-dist/web/locale/ku/*',
                 'pdfjs-dist/web/locale/lg/*',
                 'pdfjs-dist/web/locale/lij/*',
                 'pdfjs-dist/web/locale/lo/*',
                 'pdfjs-dist/web/locale/lt/*',
                 'pdfjs-dist/web/locale/ltg/*',
                 'pdfjs-dist/web/locale/lv/*',
                 'pdfjs-dist/web/locale/mai/*',
                 'pdfjs-dist/web/locale/meh/*',
                 'pdfjs-dist/web/locale/mk/*',
                 'pdfjs-dist/web/locale/ml/*',
                 'pdfjs-dist/web/locale/mn/*',
                 'pdfjs-dist/web/locale/mr/*',
                 'pdfjs-dist/web/locale/ms/*',
                 'pdfjs-dist/web/locale/my/*',
                 'pdfjs-dist/web/locale/nb-NO/*',
                 'pdfjs-dist/web/locale/ne-NP/*',
                 'pdfjs-dist/web/locale/nl/*',
                 'pdfjs-dist/web/locale/nn-NO/*',
                 'pdfjs-dist/web/locale/nso/*',
                 'pdfjs-dist/web/locale/oc/*',
                 'pdfjs-dist/web/locale/or/*',
                 'pdfjs-dist/web/locale/pa-IN/*',
                 'pdfjs-dist/web/locale/pl/*',
                 'pdfjs-dist/web/locale/pt-BR/*',
                 'pdfjs-dist/web/locale/pt-PT/*',
                 'pdfjs-dist/web/locale/rm/*',
                 'pdfjs-dist/web/locale/ro/*',
                 'pdfjs-dist/web/locale/ru/*',
                 'pdfjs-dist/web/locale/rw/*',
                 'pdfjs-dist/web/locale/sah/*',
                 'pdfjs-dist/web/locale/sat/*',
                 'pdfjs-dist/web/locale/si/*',
                 'pdfjs-dist/web/locale/sk/*',
                 'pdfjs-dist/web/locale/sl/*',
                 'pdfjs-dist/web/locale/son/*',
                 'pdfjs-dist/web/locale/sq/*',
                 'pdfjs-dist/web/locale/sr/*',
                 'pdfjs-dist/web/locale/sv-SE/*',
                 'pdfjs-dist/web/locale/sw/*',
                 'pdfjs-dist/web/locale/ta-LK/*',
                 'pdfjs-dist/web/locale/ta/*',
                 'pdfjs-dist/web/locale/te/*',
                 'pdfjs-dist/web/locale/th/*',
                 'pdfjs-dist/web/locale/tl/*',
                 'pdfjs-dist/web/locale/tn/*',
                 'pdfjs-dist/web/locale/tr/*',
                 'pdfjs-dist/web/locale/tsz/*',
                 'pdfjs-dist/web/locale/uk/*',
                 'pdfjs-dist/web/locale/ur/*',
                 'pdfjs-dist/web/locale/uz/*',
                 'pdfjs-dist/web/locale/vi/*',
                 'pdfjs-dist/web/locale/wo/*',
                 'pdfjs-dist/web/locale/xh/*',
                 'pdfjs-dist/web/locale/zam/*',
                 'pdfjs-dist/web/locale/zh-CN/*',
                 'pdfjs-dist/web/locale/zh-TW/*',
                 'pdfjs-dist/web/locale/zu/*']}

install_requires = \
['PyPDF2>=1.26.0,<2.0.0', 'PySide2>=5.14.1,<6.0.0', 'openpyxl>=3.0.3,<4.0.0']

extras_require = \
{':sys_platform == "windows"': ['pywin32>=227,<228']}

setup_kwargs = {
    'name': 'pdf-preview',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'kkzk',
    'author_email': 'shohachi.kakizaki@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.8,<3.9',
}


setup(**setup_kwargs)

==> pdf-preview-0.1.1.tar.gz: pdf-preview-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pdf_preview']

package_data = \
{'': ['*'],
 'pdf_preview': ['pdfjs-dist/*',
                 'pdfjs-dist/build/*',
                 'pdfjs-dist/web/*',
                 'pdfjs-dist/web/cmaps/*',
                 'pdfjs-dist/web/images/*',
                 'pdfjs-dist/web/locale/*',
                 'pdfjs-dist/web/locale/ach/*',
                 'pdfjs-dist/web/locale/af/*',
                 'pdfjs-dist/web/locale/ak/*',
                 'pdfjs-dist/web/locale/an/*',
                 'pdfjs-dist/web/locale/ar/*',
                 'pdfjs-dist/web/locale/as/*',
                 'pdfjs-dist/web/locale/ast/*',
                 'pdfjs-dist/web/locale/az/*',
                 'pdfjs-dist/web/locale/be/*',
                 'pdfjs-dist/web/locale/bg/*',
                 'pdfjs-dist/web/locale/bn-BD/*',
                 'pdfjs-dist/web/locale/bn-IN/*',
                 'pdfjs-dist/web/locale/br/*',
                 'pdfjs-dist/web/locale/brx/*',
                 'pdfjs-dist/web/locale/bs/*',
                 'pdfjs-dist/web/locale/ca/*',
                 'pdfjs-dist/web/locale/cak/*',
                 'pdfjs-dist/web/locale/crh/*',
                 'pdfjs-dist/web/locale/cs/*',
                 'pdfjs-dist/web/locale/csb/*',
                 'pdfjs-dist/web/locale/cy/*',
                 'pdfjs-dist/web/locale/da/*',
                 'pdfjs-dist/web/locale/de/*',
                 'pdfjs-dist/web/locale/el/*',
                 'pdfjs-dist/web/locale/en-CA/*',
                 'pdfjs-dist/web/locale/en-GB/*',
                 'pdfjs-dist/web/locale/en-US/*',
                 'pdfjs-dist/web/locale/en-ZA/*',
                 'pdfjs-dist/web/locale/eo/*',
                 'pdfjs-dist/web/locale/es-AR/*',
                 'pdfjs-dist/web/locale/es-CL/*',
                 'pdfjs-dist/web/locale/es-ES/*',
                 'pdfjs-dist/web/locale/es-MX/*',
                 'pdfjs-dist/web/locale/et/*',
                 'pdfjs-dist/web/locale/eu/*',
                 'pdfjs-dist/web/locale/fa/*',
                 'pdfjs-dist/web/locale/ff/*',
                 'pdfjs-dist/web/locale/fi/*',
                 'pdfjs-dist/web/locale/fr/*',
                 'pdfjs-dist/web/locale/fy-NL/*',
                 'pdfjs-dist/web/locale/ga-IE/*',
                 'pdfjs-dist/web/locale/gd/*',
                 'pdfjs-dist/web/locale/gl/*',
                 'pdfjs-dist/web/locale/gn/*',
                 'pdfjs-dist/web/locale/gu-IN/*',
                 'pdfjs-dist/web/locale/he/*',
                 'pdfjs-dist/web/locale/hi-IN/*',
                 'pdfjs-dist/web/locale/hr/*',
                 'pdfjs-dist/web/locale/hsb/*',
                 'pdfjs-dist/web/locale/hto/*',
                 'pdfjs-dist/web/locale/hu/*',
                 'pdfjs-dist/web/locale/hy-AM/*',
                 'pdfjs-dist/web/locale/ia/*',
                 'pdfjs-dist/web/locale/id/*',
                 'pdfjs-dist/web/locale/is/*',
                 'pdfjs-dist/web/locale/it/*',
                 'pdfjs-dist/web/locale/ja/*',
                 'pdfjs-dist/web/locale/ka/*',
                 'pdfjs-dist/web/locale/kab/*',
                 'pdfjs-dist/web/locale/kk/*',
                 'pdfjs-dist/web/locale/km/*',
                 'pdfjs-dist/web/locale/kn/*',
                 'pdfjs-dist/web/locale/ko/*',
                 'pdfjs-dist/web/locale/kok/*',
                 'pdfjs-dist/web/locale/ks/*',
                 'pdfjs-dist/web/locale/ku/*',
                 'pdfjs-dist/web/locale/lg/*',
                 'pdfjs-dist/web/locale/lij/*',
                 'pdfjs-dist/web/locale/lo/*',
                 'pdfjs-dist/web/locale/lt/*',
                 'pdfjs-dist/web/locale/ltg/*',
                 'pdfjs-dist/web/locale/lv/*',
                 'pdfjs-dist/web/locale/mai/*',
                 'pdfjs-dist/web/locale/meh/*',
                 'pdfjs-dist/web/locale/mk/*',
                 'pdfjs-dist/web/locale/ml/*',
                 'pdfjs-dist/web/locale/mn/*',
                 'pdfjs-dist/web/locale/mr/*',
                 'pdfjs-dist/web/locale/ms/*',
                 'pdfjs-dist/web/locale/my/*',
                 'pdfjs-dist/web/locale/nb-NO/*',
                 'pdfjs-dist/web/locale/ne-NP/*',
                 'pdfjs-dist/web/locale/nl/*',
                 'pdfjs-dist/web/locale/nn-NO/*',
                 'pdfjs-dist/web/locale/nso/*',
                 'pdfjs-dist/web/locale/oc/*',
                 'pdfjs-dist/web/locale/or/*',
                 'pdfjs-dist/web/locale/pa-IN/*',
                 'pdfjs-dist/web/locale/pl/*',
                 'pdfjs-dist/web/locale/pt-BR/*',
                 'pdfjs-dist/web/locale/pt-PT/*',
                 'pdfjs-dist/web/locale/rm/*',
                 'pdfjs-dist/web/locale/ro/*',
                 'pdfjs-dist/web/locale/ru/*',
                 'pdfjs-dist/web/locale/rw/*',
                 'pdfjs-dist/web/locale/sah/*',
                 'pdfjs-dist/web/locale/sat/*',
                 'pdfjs-dist/web/locale/si/*',
                 'pdfjs-dist/web/locale/sk/*',
                 'pdfjs-dist/web/locale/sl/*',
                 'pdfjs-dist/web/locale/son/*',
                 'pdfjs-dist/web/locale/sq/*',
                 'pdfjs-dist/web/locale/sr/*',
                 'pdfjs-dist/web/locale/sv-SE/*',
                 'pdfjs-dist/web/locale/sw/*',
                 'pdfjs-dist/web/locale/ta-LK/*',
                 'pdfjs-dist/web/locale/ta/*',
                 'pdfjs-dist/web/locale/te/*',
                 'pdfjs-dist/web/locale/th/*',
                 'pdfjs-dist/web/locale/tl/*',
                 'pdfjs-dist/web/locale/tn/*',
                 'pdfjs-dist/web/locale/tr/*',
                 'pdfjs-dist/web/locale/tsz/*',
                 'pdfjs-dist/web/locale/uk/*',
                 'pdfjs-dist/web/locale/ur/*',
                 'pdfjs-dist/web/locale/uz/*',
                 'pdfjs-dist/web/locale/vi/*',
                 'pdfjs-dist/web/locale/wo/*',
                 'pdfjs-dist/web/locale/xh/*',
                 'pdfjs-dist/web/locale/zam/*',
                 'pdfjs-dist/web/locale/zh-CN/*',
                 'pdfjs-dist/web/locale/zh-TW/*',
                 'pdfjs-dist/web/locale/zu/*']}

install_requires = \
['PyPDF2>=1.26.0,<2.0.0',
 'PySide2>=5.14.1,<6.0.0',
 'openpyxl>=3.0.3,<4.0.0',
 'pywin32>=227,<228']

setup_kwargs = {
    'name': 'pdf-preview',
    'version': '0.1.1',
    'description': 'PDF Previewer for Excel / Word document.',
    'long_description': 'pdf-preview\n===========\n\nPreview Excel/Word documents via PDF.\n\nInstall\n-------\n::\n\n  py -m pip install pdf-preview\n  py -m pdf_preview -i\n\nThis command adds a registry KEY\n``HKEY_CLASSES_ROOT\\Directory\\shell\\pdf_Preview.convert\\command``\nand default VALUE ``<python executable> -m pdf_preview "%1"``.\nYou will see context menu for directory. Select it for execute PDF Preview application.\nWhen you select a Word / Excel document in the tree, the result converted to pdf is displayed.\n\nDependencies\n------------\n\n- pywin32\n- PyPDF2\n- PySide2\n- openpyxl\n\nand their requirement packages.\n\nUses\n----\n\n- PDFjs(included)\n',
    'author': 'kkzk',
    'author_email': 'shohachi.kakizaki@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/kkzk/pdf-preview',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.9',
}


setup(**setup_kwargs)
